@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.50';
+$Test::BDD::Cucumber::Executor::VERSION = '0.51';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.50
+version 0.51
 
 =head1 DESCRIPTION
 
@@ -219,10 +219,10 @@ the Harness interface.
 sub execute_scenario {
     my ( $self, $options ) = @_;
     my ( $feature, $feature_stash, $harness, $outline, $background_obj,
-        $incoming_scenario_stash, $incoming_outline_stash )
+        $incoming_scenario_stash, $incoming_outline_state )
       = @$options{
         qw/ feature feature_stash harness scenario background scenario_stash
-          outline_stash
+          outline_state
           /
       };
 
@@ -231,8 +231,8 @@ sub execute_scenario {
     my $harness_start = $is_background ? 'background'      : 'scenario';
     my $harness_stop  = $is_background ? 'background_done' : 'scenario_done';
 
-    my $outline_stash = $incoming_outline_stash || {};
-    $outline_stash->{'short_circuit'} ||= $self->_bail_out;
+    my $outline_state = $incoming_outline_state || {};
+    $outline_state->{'short_circuit'} ||= $self->_bail_out;
 
     # Multiply out Scenario Outlines as appropriate
     my @datasets = @{ $outline->data };
@@ -280,11 +280,11 @@ sub execute_scenario {
 
                 my $result =
                   $self->dispatch( $context, $before_step,
-                    $outline_stash->{'short_circuit'}, 0 );
+                    $outline_state->{'short_circuit'}, 0 );
 
                 # If it didn't pass, short-circuit the rest
                 unless ( $result->result eq 'passing' ) {
-                    $outline_stash->{'short_circuit'} = 1;
+                    $outline_state->{'short_circuit'} = 1;
                 }
             }
         }
@@ -300,7 +300,7 @@ sub execute_scenario {
                     feature_stash  => $feature_stash,
                     harness        => $harness,
                     scenario_stash => $scenario_stash,
-                    outline_stash  => $outline_stash
+                    outline_state  => $outline_state
                 }
             );
         }
@@ -335,11 +335,11 @@ sub execute_scenario {
 
             my $result =
               $self->find_and_dispatch( $context,
-                $outline_stash->{'short_circuit'}, 0 );
+                $outline_state->{'short_circuit'}, 0 );
 
             # If it didn't pass, short-circuit the rest
             unless ( $result->result eq 'passing' ) {
-                $outline_stash->{'short_circuit'}++;
+                $outline_state->{'short_circuit'}++;
             }
 
         }
@@ -355,7 +355,7 @@ sub execute_scenario {
                 my $result = $self->dispatch( $context, $after_step, 0, 0 );
             }
             $_->post_scenario( $outline, $feature_stash, $scenario_stash,
-                $outline_stash->{'short_circuit'} )
+                $outline_state->{'short_circuit'} )
               for reverse @{ $self->extensions };
 
         }
@@ -496,6 +496,7 @@ sub dispatch {
 
     # New scope for the localization
     my $result;
+    my $stash_keys = join ';', sort keys %{$context->stash};
     {
         # Localize test builder
         local $Test::Builder::Test->{'_wraps'} = $tb_return->{'builder'};
@@ -551,6 +552,8 @@ sub dispatch {
             }
         );
     }
+    warn qq|Unsupported: Step modified C->stash instead of C->stash->{scenario} or C->stash->{feature}|
+        if $stash_keys ne (join ';', sort keys %{$context->stash});
 
     my @clean_matches =
       $self->_extract_match_strings( $context->text, \@match_locations );
