@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::JSON;
-$Test::BDD::Cucumber::Harness::JSON::VERSION = '0.49';
+$Test::BDD::Cucumber::Harness::JSON::VERSION = '0.51';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::JSON - Generate results to JSON file
 
 =head1 VERSION
 
-version 0.49
+version 0.51
 
 =head1 DESCRIPTION
 
@@ -64,6 +64,11 @@ sub scenario {
     push @{ $self->current_feature->{elements} }, $self->current_scenario;
 }
 
+sub scenario_done {
+    my $self = shift;
+    $self->current_scenario( {} );
+}
+
 sub step {
     my ( $self, $context ) = @_;
     $self->step_start_at( time() );
