@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::TestBuilder;
-$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.49';
+$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.51';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TestBuilder - Pipes step output via Test::Builder
 
 =head1 VERSION
 
-version 0.49
+version 0.51
 
 =head1 DESCRIPTION
 
@@ -28,24 +28,31 @@ use Test::More;
 
 extends 'Test::BDD::Cucumber::Harness';
 has 'fail_skip' => ( is => 'rw', isa => 'Bool', default => 0 );
+has '_tb_instance' => ( is => 'rw', isa => 'Test::Builder' );
 
 my $li = ' ' x 7;
 my $ni = ' ' x 4;
 my $si = ' ' x 9;
 my $di = ' ' x 17;
 
+sub _tb {
+    my $self = shift;
+    return $self->_tb_instance || Test::Builder->new();
+}
+
 sub feature {
     my ( $self, $feature ) = @_;
-    note "${li}Feature: " . $feature->name;
-    note "$li$ni" . $_->content for @{ $feature->satisfaction };
-    note "";
+    $self->_tb->note( "${li}Feature: " . $feature->name );
+    $self->_tb->note( "$li$ni" . $_->content )
+        for @{ $feature->satisfaction };
+    $self->_tb->note("");
 }
 
 sub scenario {
     my ( $self, $scenario, $dataset ) = @_;
-    note "$li${ni}Scenario: " . ( $scenario->name || '' );
+    $self->_tb->note( "$li${ni}Scenario: " . ( $scenario->name || '' ) );
 }
-sub scenario_done { note ""; }
+sub scenario_done { my $self = shift; $self->_tb->note(""); }
 
 sub step { }
 
@@ -59,42 +66,43 @@ sub step_done {
 
     if ( $context->is_hook ) {
         $status ne 'undefined'
-          and $status ne 'pending'
-          and $status ne 'passing'
-          or return;
+            and $status ne 'pending'
+            and $status ne 'passing'
+            or return;
         $step_name = 'In ' . ucfirst( $context->verb ) . ' Hook';
     } else {
-        $step_name =
-          $si . ucfirst( $step->verb_original ) . ' ' . $context->text;
+        $step_name
+            = $si . ucfirst( $step->verb_original ) . ' ' . $context->text;
     }
 
     if ( $status eq 'undefined' || $status eq 'pending' ) {
         if ( $self->fail_skip ) {
             if ( $status eq 'undefined' ) {
-                fail("No matcher for: $step_name");
+                $self->_tb->ok( 0, "No matcher for: $step_name" );
             } else {
-                fail("Test skipped due to failure in previous step");
+                $self->_tb->ok( 0,
+                    "Test skipped due to failure in previous step" );
             }
             $self->_note_step_data($step);
         } else {
-          TODO: { todo_skip $step_name, 1 }
+        TODO: { todo_skip $step_name, 1 }
             $self->_note_step_data($step);
         }
     } elsif ( $status eq 'passing' ) {
-        pass($step_name);
+        $self->_tb->ok( 1, $step_name );
         $self->_note_step_data($step);
     } else {
-        fail($step_name);
+        $self->_tb->ok( 0, $step_name );
         $self->_note_step_data($step);
         if ( !$context->is_hook ) {
-            my $step_location =
-                '  in step at '
-              . $step->line->document->filename
-              . ' line '
-              . $step->line->number . '.';
-            diag($step_location);
+            my $step_location
+                = '  in step at '
+                . $step->line->document->filename
+                . ' line '
+                . $step->line->number . '.';
+            $self->_tb->diag($step_location);
         }
-        diag( $result->output );
+        $self->_tb->diag( $result->output );
     }
 }
 
@@ -106,18 +114,18 @@ sub _note_step_data {
 
     if ( ref( $step->data ) eq 'ARRAY' ) {
         for (@step_data) {
-            note( $di . $_ );
+            $self->_tb->note( $di . $_ );
         }
     } else {
-        note $di . '"""';
+        $self->_tb->note( $di . '"""' );
         for (@step_data) {
-            note( $di . '  ' . $_ );
+            $self->_tb->note( $di . '  ' . $_ );
         }
-        note $di . '"""';
+        $self->_tb->note( $di . '"""' );
     }
 }
 
-sub shutdown { done_testing(); }
+sub shutdown { my $self = shift; $self->_tb->note( $self->_tb->done_testing() ); }
 
 =head1 AUTHOR
 
