@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Model::TagSpec;
-$Test::BDD::Cucumber::Model::TagSpec::VERSION = '0.49';
+$Test::BDD::Cucumber::Model::TagSpec::VERSION = '0.51';
 =head1 NAME
 
 Test::BDD::Cucumber::Model::TagSpec - Encapsulates tag selectors
 
 =head1 VERSION
 
-version 0.49
+version 0.51
 
 =head1 DESCRIPTION
 
@@ -38,11 +38,11 @@ don't do that. The C<not> function accepts only one argument.
 
 I<eg>:
 
-@important AND @billing: C<[and => 'important', 'billing']>
+@important AND @billing: C<<[and => 'important', 'billing']>>
 
-(@billing OR @WIP) AND @important: C<[ and => [ or => 'billing', 'wip' ], 'important' ]>
+(@billing OR @WIP) AND @important: C<<[ and => [ or => 'billing', 'wip' ], 'important' ]>>
 
-Skipping both @todo and @wip tags: C<[ and => [ not => 'todo' ], [ not => 'wip' ] ]>
+Skipping both @todo and @wip tags: C<<[ and => [ not => 'todo' ], [ not => 'wip' ] ]>>
 
 =head1 ATTRIBUTES
 
@@ -51,7 +51,7 @@ Skipping both @todo and @wip tags: C<[ and => [ not => 'todo' ], [ not => 'wip'
 An arrayref representing a structure like the above.
 
  TagSet->new({
-	tags => [ and => 'green', 'blue', [ or => 'red', 'yellow' ], [ not => 'white' ] ]
+        tags => [ and => 'green', 'blue', [ or => 'red', 'yellow' ], [ not => 'white' ] ]
  })
 
 =cut
