@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.50';
+$Test::BDD::Cucumber::Parser::VERSION = '0.51';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.50
+version 0.51
 
 =head1 DESCRIPTION
 
@@ -46,20 +46,19 @@ use Test::BDD::Cucumber::Errors qw/parse_error_from_line/;
 # https://github.com/cucumber/cucumber/wiki/Scenario-outlines
 
 sub parse_string {
-    my ( $class, $string, $tag_scheme ) = @_;
+    my ( $class, $string ) = @_;
 
     return $class->_construct(
         Test::BDD::Cucumber::Model::Document->new(
             {
                 content => $string
             }
-        ),
-        $tag_scheme
+        )
     );
 }
 
 sub parse_file {
-    my ( $class, $string, $tag_scheme ) = @_;
+    my ( $class, $string ) = @_;
     return $class->_construct(
         Test::BDD::Cucumber::Model::Document->new(
             {
@@ -67,13 +66,12 @@ sub parse_file {
                   scalar( read_file( $string, { binmode => ':utf8' } ) ),
                 filename => '' . $string
             }
-        ),
-        $tag_scheme
+        )
     );
 }
 
 sub _construct {
-    my ( $class, $document, $tag_scheme ) = @_;
+    my ( $class, $document ) = @_;
 
     my $feature =
       Test::BDD::Cucumber::Model::Feature->new( { document => $document } );
