@@ -1,18 +1,19 @@
 package Test::BDD::Cucumber::StepFile;
-$Test::BDD::Cucumber::StepFile::VERSION = '0.49';
+$Test::BDD::Cucumber::StepFile::VERSION = '0.51';
 =head1 NAME
 
 Test::BDD::Cucumber::StepFile - Functions for creating and loading Step Definitions
 
 =head1 VERSION
 
-version 0.49
+version 0.51
 
 =cut
 
 use strict;
 use warnings;
 use Carp qw/croak/;
+use File::Spec qw/rel2abs/;
 
 use Test::BDD::Cucumber::I18n qw(languages langdef keyword_to_subname);
 require Exporter;
@@ -149,7 +150,9 @@ sub load {
     my ( $class, $filename ) = @_;
     {
         local @definitions;
-        do $filename;
+
+        # Debian Jessie with security patches requires an absolute path
+        do File::Spec->rel2abs($filename);
         die "Step file [$filename] failed to load: $@" if $@;
         return @definitions;
     }
